library own_appbar;

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

// ignore: must_be_immutable
class OwnAppBar extends StatefulWidget with PreferredSizeWidget {
  IconData? leadingIcon;
  Key? key;
  IconData? tailingIcon;
  Function(String)? actionClicked;
  String? logoID;
  Widget? centerChild;
  Color backgroundColor;
  Color leadingColor;
  Color tailingColor;
  final BuildContext context;
  double sizeFactor;
  double iconFactor;

  OwnAppBar({
    this.leadingIcon,
    this.key,
    this.tailingIcon,
    this.sizeFactor = 18,
    this.iconFactor = 1.8,
    this.actionClicked,
    this.logoID,
    this.centerChild,
    this.backgroundColor = Colors.white,
    this.leadingColor = Colors.black,
    this.tailingColor = Colors.black,
    required this.context,
  })  : assert(
          sizeFactor >= 15 && sizeFactor <= 20,
        ),
        assert(
          iconFactor >= 1.5 && iconFactor <= 2,
        ),
        super(key: key);

  @override
  _OwnAppBarState createState() => _OwnAppBarState();

  @override
  Size get preferredSize => Size(
        MediaQuery.of(context).size.width,
        MediaQuery.of(context).size.height / sizeFactor,
      );
}

class _OwnAppBarState extends State<OwnAppBar> {
  double get appBarHeight {
    return widget.preferredSize.height;
  }

  @override
  Widget build(BuildContext context) {
    if (kDebugMode) {
      print("For this device AppBar size will be: ${widget.preferredSize}");
    }
    return Container(
      color: widget.backgroundColor,
      padding: EdgeInsets.all(widget.preferredSize.height / 20),
      child: Stack(
        children: [
          Align(
            alignment: Alignment(-0.98, 0),
            child: widget.leadingIcon != null
                ? InkWell(
                    splashColor: Colors.transparent,
                    highlightColor: Colors.transparent,
                    onTap: () {
                      if (widget.actionClicked != null)
                        widget.actionClicked!.call("leading_clicked");
                    },
                    child: Padding(
                      padding: EdgeInsets.all(appBarHeight / 9),
                      child: Icon(
                        widget.leadingIcon,
                        size: appBarHeight / widget.iconFactor,
                        color: widget.leadingColor,
                      ),
                    ),
                  )
                : SizedBox.shrink(),
          ),
          Align(
            alignment: Alignment(0, 0),
            child: widget.centerChild != null
                ? widget.centerChild
                : widget.logoID != null
                    ? ConstrainedBox(
                        constraints: BoxConstraints(
                            maxHeight: appBarHeight,
                            maxWidth:
                                MediaQuery.of(widget.context).size.height / 2),
                        child: Image.asset(widget.logoID!),
                      )
                    : SizedBox.shrink(),
          ),
          Align(
            alignment: Alignment(.98, 0),
            child: widget.tailingIcon != null
                ? InkWell(
                    splashColor: Colors.transparent,
                    highlightColor: Colors.transparent,
                    onTap: () {
                      if (widget.actionClicked != null)
                        widget.actionClicked!.call("tailing_clicked");
                    },
                    child: Padding(
                      padding: EdgeInsets.all(appBarHeight / 9),
                      child: Icon(
                        widget.tailingIcon,
                        color: widget.tailingColor,
                        size: appBarHeight / widget.iconFactor,
                      ),
                    ),
                  )
                : SizedBox.shrink(),
          )
        ],
      ),
    );
  }
}
